@@ -81,7 +81,7 @@ test_no_workon_home () {
     export WORKON_HOME="$WORKON_HOME/not_there"
     mkvirtualenv should_be_created >"$old_home/output" 2>&1
     output=$(cat "$old_home/output")
-    assertTrue "Did not see expected message" "echo $output | grep 'does not exist'"
+    assertTrue "Did not see expected message in \"$output\"" "cat \"$old_home/output\" | grep 'does not exist'"
     assertTrue "Did not create environment" "[ -d \"$WORKON_HOME/should_be_created\" ]"
     WORKON_HOME="$old_home"
 }
